[Python-checkins] distutils2: correct a typo

tarek.ziade python-checkins at python.org
Sun Jul 4 11:48:40 CEST 2010


tarek.ziade pushed 1b75f9a8dd54 to distutils2:

http://hg.python.org/distutils2/rev/1b75f9a8dd54
changeset:   320:1b75f9a8dd54
user:        Alexis Metaireau <ametaireau at gmail.com>
date:        Tue Jun 22 16:17:44 2010 +0200
summary:     correct a typo
files:       docs/source/pypi.rst, src/distutils2/pypi/dist.py, src/distutils2/pypi/simple.py, src/distutils2/tests/test_pypi_simple.py

diff --git a/docs/source/pypi.rst b/docs/source/pypi.rst
--- a/docs/source/pypi.rst
+++ b/docs/source/pypi.rst
@@ -6,11 +6,11 @@
 facilities to access the Python Package Index (named "pypi", and avalaible on
 the url `http://pypi.python.org`.
 
-There is two ways to retreive data from pypi: using the *simple* API, and using
+There is two ways to retrieve data from pypi: using the *simple* API, and using
 *XML-RPC*. The first one is in fact a set of HTML pages avalaible at
 `http://pypi.python.org/simple/`. In order to reduce the overload caused by
 running distant methods on the pypi server (by using the XML-RPC methods), the
-best way to retreive informations is by using the simple API.
+best way to retrieve informations is by using the simple API.
 
 Distutils2 provides two python modules to ease the work with those two APIs:
 `distutils2.pypi.simple` and `distutils2.pypi.xmlrpc`.
diff --git a/src/distutils2/pypi/simple.py b/src/distutils2/pypi/simple.py
--- a/src/distutils2/pypi/simple.py
+++ b/src/distutils2/pypi/simple.py
@@ -1,6 +1,6 @@
 """pypi.simple
 
-Contains the class "SimpleIndex", a simple spider to find and retreive
+Contains the class "SimpleIndex", a simple spider to find and retrieve
 distributions on the Python Package Index, using it's "simple" API,
 avalaible at http://pypi.python.org/simple/
 """
diff --git a/src/distutils2/tests/test_pypi_simple.py b/src/distutils2/tests/test_pypi_simple.py
--- a/src/distutils2/tests/test_pypi_simple.py
+++ b/src/distutils2/tests/test_pypi_simple.py
@@ -153,7 +153,7 @@
     def test_disable_external_pages(self, server):
         """Exclude external pages if disabled
         """
-        # Test that telling the simple pyPI client to not retreive external
+        # Test that telling the simple pyPI client to not retrieve external
         # works
         index = self._get_simple_index(server, hosts=(server.full_address,))
         index.get("foobar")

diff --git a/src/distutils2/pypi/dist.py b/src/distutils2/pypi/dist.py
--- a/src/distutils2/pypi/dist.py
+++ b/src/distutils2/pypi/dist.py
@@ -1,6 +1,6 @@
 """distutils2.pypi.dist
 
-Provides the PyPIDistribution class thats represents a distribution retreived
+Provides the PyPIDistribution class thats represents a distribution retrieved
 on PyPI.
 """
 import re
@@ -20,7 +20,7 @@
 
 
 class PyPIDistribution(object):
     """Represents a distribution retreived from PyPI.
 
     This is a simple container for various attributes as name, version,
     location, url etc.
@@ -20,7 +20,7 @@
 
 class PyPIDistribution(object):
-    """Represents a distribution retreived from PyPI.
+    """Represents a distribution retrieved from PyPI.
 
     This is a simple container for various attributes as name, version,
--
Repository URL: http://hg.python.org/distutils2


More information about the Python-checkins mailing list